GoogleSignInArgs class

Inheritance

Constructors

GoogleSignInArgs({required String clientId, required String redirectUri, String scope = _defaultSignInScope, bool immediate = false, String responseType = 'token id_token'})

Properties

clientId → String
final
hashCode → int
The hash code for this object.
no setterinherited
host → String
final
immediate → bool
final
path → String
final
redirectUri → String
final
responseType → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → String
final
usesFragment ↔ bool
getter/setter pairinherited

Methods

authorizeFromCallback(String callbackUrl) → Future<AuthResult?>
inherited
buildQueryParameters() → Map<String, String>
override
buildSignInUri() → Future<String>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Future<Map<String, String>>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited